==> copilot-24.5.0-sources.jar: com/vaadin/copilot/UiServiceHandler.java <==
package com.vaadin.copilot;

import java.util.Arrays;
import java.util.List;

import com.vaadin.base.devserver.DevToolsInterface;
import com.vaadin.flow.internal.JsonUtils;
import com.vaadin.flow.server.VaadinServletContext;

import elemental.json.Json;
import elemental.json.JsonArray;
import elemental.json.JsonObject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/** Provides endpoint information to the client. */
public class UiServiceHandler implements CopilotCommand {
    private final ProjectManager projectManager;
    private final VaadinServletContext context;

    /**
     * Creates a new endpoint handler.
     *
     * @param projectManager
     *            the project manager to use
     * @param context
     *            the servlet context to use
     */
    public UiServiceHandler(ProjectManager projectManager, VaadinServletContext context) {
        this.projectManager = projectManager;
        this.context = context;
    }

    @Override
    public boolean handleMessage(String command, JsonObject data, DevToolsInterface devToolsInterface) {
        if (command.equals("get-browser-callables")) {
            JsonObject returnData = Json.createObject();
            returnData.put("reqId", data.getString("reqId"));
            List<SpringBridge.EndpointInfo> browserCallables = SpringBridge.getEndpoints(context);

            JsonArray browserCallableJson = browserCallables.stream().sorted(UiServiceHandler::sortByClassName)
                    .map(browserCallable -> {
                        JsonObject json = Json.createObject();
                        json.put("className", browserCallable.endpointClass().getName());
                        json.put("filename",
                                projectManager.getFileForClass(browserCallable.endpointClass()).getAbsolutePath());
                        json.put("lineNumber", 1);
                        json.put("methodName", browserCallable.method().getName());
                        json.put("parameters", Arrays.stream(browserCallable.method().getParameters()).map(param -> {
                            JsonObject paramInfo = Json.createObject();
                            paramInfo.put("name", param.getName());
                            paramInfo.put("type", param.getType().getName());
                            return paramInfo;
                        }).collect(JsonUtils.asArray()));

                        try {
                            AccessRequirement req = AccessRequirementUtil.getAccessRequirement(browserCallable.method(),
                                    browserCallable.endpointClass());
                            json.put("accessRequirement", JsonUtils.beanToJson(req));
                        } catch (Exception e) {
                            getLogger().error("Unable to determine access requirement", e);
                        }
                        return json;
                    }).collect(JsonUtils.asArray());

            returnData.put("browserCallables", browserCallableJson);

            devToolsInterface.send("resp" + command, returnData);
            return true;
        }
        return false;
    }

    public static int sortByClassName(SpringBridge.EndpointInfo e1, SpringBridge.EndpointInfo e2) {
        if (!e1.endpointClass().equals(e2.endpointClass())) {
            return e1.endpointClass().getName().compareTo(e2.endpointClass().getName());
        } else {
            return e1.method().getName().compareTo(e2.method().getName());
        }
    }

    private static Logger getLogger() {
        return LoggerFactory.getLogger(UiServiceHandler.class);
    }
}

==> copilot-24.5.5-sources.jar: com/vaadin/copilot/UiServiceHandler.java <==
package com.vaadin.copilot;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.vaadin.base.devserver.DevToolsInterface;
import com.vaadin.flow.internal.JsonUtils;
import com.vaadin.flow.internal.hilla.EndpointRequestUtil;
import com.vaadin.flow.server.VaadinServletContext;

import elemental.json.Json;
import elemental.json.JsonArray;
import elemental.json.JsonObject;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/** Provides endpoint information to the client. */
public class UiServiceHandler implements CopilotCommand {
    private final ProjectManager projectManager;
    private final VaadinServletContext context;

    /**
     * Creates a new endpoint handler.
     *
     * @param projectManager
     *            the project manager to use
     * @param context
     *            the servlet context to use
     */
    public UiServiceHandler(ProjectManager projectManager, VaadinServletContext context) {
        this.projectManager = projectManager;
        this.context = context;
    }

    @Override
    public boolean handleMessage(String command, JsonObject data, DevToolsInterface devToolsInterface) {
        if (command.equals("get-browser-callables")) {
            JsonObject returnData = Json.createObject();
            returnData.put("reqId", data.getString("reqId"));
            List<SpringBridge.EndpointInfo> browserCallables = EndpointRequestUtil.isHillaAvailable()
                    ? SpringBridge.getEndpoints(context)
                    : new ArrayList<>();

            JsonArray browserCallableJson = browserCallables.stream().sorted(UiServiceHandler::sortByClassName)
                    .map(browserCallable -> {
                        JsonObject json = Json.createObject();
                        json.put("className", browserCallable.endpointClass().getName());
                        json.put("filename",
                                projectManager.getFileForClass(browserCallable.endpointClass()).getAbsolutePath());
                        json.put("lineNumber", 1);
                        json.put("methodName", browserCallable.method().getName());
                        json.put("parameters", Arrays.stream(browserCallable.method().getParameters()).map(param -> {
                            JsonObject paramInfo = Json.createObject();
                            paramInfo.put("name", param.getName());
                            paramInfo.put("type", param.getType().getName());
                            return paramInfo;
                        }).collect(JsonUtils.asArray()));

                        try {
                            AccessRequirement req = AccessRequirementUtil.getAccessRequirement(browserCallable.method(),
                                    browserCallable.endpointClass());
                            json.put("accessRequirement", JsonUtils.beanToJson(req));
                        } catch (Exception e) {
                            getLogger().error("Unable to determine access requirement", e);
                        }
                        return json;
                    }).collect(JsonUtils.asArray());

            returnData.put("browserCallables", browserCallableJson);

            devToolsInterface.send("resp" + command, returnData);
            return true;
        }
        return false;
    }

    public static int sortByClassName(SpringBridge.EndpointInfo e1, SpringBridge.EndpointInfo e2) {
        if (!e1.endpointClass().equals(e2.endpointClass())) {
            return e1.endpointClass().getName().compareTo(e2.endpointClass().getName());
        } else {
            return e1.method().getName().compareTo(e2.method().getName());
        }
    }

    private static Logger getLogger() {
        return LoggerFactory.getLogger(UiServiceHandler.class);
    }
}
